# {{plugin_name}} Documentation

Welcome to the documentation for {{plugin_name}}!

{{plugin_name}} is a Maestria plugin that provides additional functionality for Python projects.

## Getting Started

- [Installation](./installation.md)
- [Quick Start](./quickstart.md)
- [Configuration](./configuration.md)

## Features

### Commands

The {{plugin_name}} plugin provides the following commands:

- [`hello`](./commands/hello.md): Say hello to someone
- [`analyze`](./commands/analyze.md): Analyze a Python project

[Learn more about the commands](./commands/index.md)

### Hooks

The plugin provides hooks that integrate with Maestria's command lifecycle:

- Pre-command hook: Runs before any Maestria command
- Post-command hook: Runs after any Maestria command

[Learn more about hooks](./hooks/index.md)

### Templates

The plugin includes example templates for creating projects that use {{plugin_name}}.

## Development

- [Contributing](./development/contributing.md)
- [Plugin Structure](./development/structure.md)
- [Creating Commands](./development/commands.md)
- [Creating Hooks](./development/hooks.md)